==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebGridDataBindableDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridDataBindableDescription } from "./WebGridDataBindableDescription";
/**
 * @hidden
 */
var WebGridDataBindableDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridDataBindableDescriptionMetadata, _super);
    function WebGridDataBindableDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridDataBindableDescriptionMetadata.b = function (a) {
        if (WebGridDataBindableDescriptionMetadata.a == null) {
            WebGridDataBindableDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridDataBindableDescriptionMetadata.c(WebGridDataBindableDescriptionMetadata.a);
        }
        if (a.j(WebGridDataBindableDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridDataBindableDescriptionMetadata.a);
    };
    WebGridDataBindableDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridDataBindable");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("DataRef", "(w:Data,wf:Data)DataRef:object");
        a.item("FilteredDataRef", "(w:FilteredData,wf:FilteredData)DataRef:object");
    };
    WebGridDataBindableDescriptionMetadata.d = function (a) {
        WebGridDataBindableDescriptionMetadata.b(a);
        a.aa("WebGridDataBindable", function () { return new WebGridDataBindableDescription(); });
        a.z("WebGridDataBindable", WebGridDataBindableDescriptionMetadata.a);
    };
    WebGridDataBindableDescriptionMetadata.$t = markType(WebGridDataBindableDescriptionMetadata, 'WebGridDataBindableDescriptionMetadata');
    WebGridDataBindableDescriptionMetadata.a = null;
    return WebGridDataBindableDescriptionMetadata;
}(Base));
export { WebGridDataBindableDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebGridDataBindableDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridDataBindableDescription } from "./WebGridDataBindableDescription";
/**
 * @hidden
 */
var WebGridDataBindableDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridDataBindableDescriptionMetadata, _super);
    function WebGridDataBindableDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridDataBindableDescriptionMetadata.b = function (a) {
        if (WebGridDataBindableDescriptionMetadata.a == null) {
            WebGridDataBindableDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridDataBindableDescriptionMetadata.c(WebGridDataBindableDescriptionMetadata.a);
        }
        if (a.k(WebGridDataBindableDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridDataBindableDescriptionMetadata.a);
    };
    WebGridDataBindableDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridDataBindable");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("DataRef", "(w:Data,wf:Data)DataRef:object");
        a.item("FilteredDataRef", "(w:FilteredData,wf:FilteredData)DataRef:object");
    };
    WebGridDataBindableDescriptionMetadata.d = function (a) {
        WebGridDataBindableDescriptionMetadata.b(a);
        a.ac("WebGridDataBindable", function () { return new WebGridDataBindableDescription(); });
        a.ab("WebGridDataBindable", WebGridDataBindableDescriptionMetadata.a);
    };
    WebGridDataBindableDescriptionMetadata.$t = markType(WebGridDataBindableDescriptionMetadata, 'WebGridDataBindableDescriptionMetadata');
    WebGridDataBindableDescriptionMetadata.a = null;
    return WebGridDataBindableDescriptionMetadata;
}(Base));
export { WebGridDataBindableDescriptionMetadata };
